==> alg-alg-1.11.8-20190508.055520-2-sources.jar: cn/com/duiba/nezha/alg/alg/vo/AdvertSupportInfoDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

public class AdvertSupportInfoDo {

    /**
     * 广告
     */
    private Long advertId;


    /**
     * 配置ID
     */
    private Long planId;

    /**
     * 目标出价（落地页点击出价）
     */
    private Long aFee;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * 全局消耗
     */
    private Long consume;

    /**
     * 广告位消耗
     */
    private Long slotConsume;

    /**
     * 全局落地页点击PV（转化）
     */
    private Long landingPageClickPV;

    /**
     * 广告位落地页点击PV（转化）
     */
    private Long slotLandingPageClickPV;



    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getConsume() {
        return consume;
    }

    public void setConsume(Long consume) {
        this.consume = consume;
    }

    public Long getSlotConsume() {
        return slotConsume;
    }

    public void setSlotConsume(Long slotConsume) {
        this.slotConsume = slotConsume;
    }

    public Long getLandingPageClickPV() {
        return landingPageClickPV;
    }

    public void setLandingPageClickPV(Long landingPageClickPV) {
        this.landingPageClickPV = landingPageClickPV;
    }

    public Long getSlotLandingPageClickPV() {
        return slotLandingPageClickPV;
    }

    public void setSlotLandingPageClickPV(Long slotLandingPageClickPV) {
        this.slotLandingPageClickPV = slotLandingPageClickPV;
    }

}

==> alg-alg-1.11.11-20190510.071637-2-sources.jar: cn/com/duiba/nezha/alg/alg/vo/AdvertSupportInfoDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

public class AdvertSupportInfoDo {

    /**
     * 广告
     */
    private Long advertId;


    /**
     * 配置ID
     */
    private Long planId;

    /**
     * 目标出价（落地页点击出价）
     */
    private Long aFee;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * 全局消耗
     */
    private Long consume;

    /**
     * 广告位消耗
     */
    private Long slotConsume;

    /**
     * 全局落地页点击PV（转化）
     */
    private Long landingPageClickPV;

    /**
     * 广告位落地页点击PV（转化）
     */
    private Long slotLandingPageClickPV;


    /**
     * 潜力广告扶持
     */
    private Integer advertSupportType;//0-新广告 1-潜力广告



    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getConsume() {
        return consume;
    }

    public void setConsume(Long consume) {
        this.consume = consume;
    }

    public Long getSlotConsume() {
        return slotConsume;
    }

    public void setSlotConsume(Long slotConsume) {
        this.slotConsume = slotConsume;
    }

    public Long getLandingPageClickPV() {
        return landingPageClickPV;
    }

    public void setLandingPageClickPV(Long landingPageClickPV) {
        this.landingPageClickPV = landingPageClickPV;
    }

    public Long getSlotLandingPageClickPV() {
        return slotLandingPageClickPV;
    }

    public void setSlotLandingPageClickPV(Long slotLandingPageClickPV) {
        this.slotLandingPageClickPV = slotLandingPageClickPV;
    }
    public Integer getAdvertSupportType() {
        return advertSupportType;
    }

    public void setAdvertSupportType(Integer advertSupoortType) {
        this.advertSupportType = advertSupoortType;
    }

}
